@@ -1,22 +1,26 @@
+# -*- coding: utf-8 -*-
+
+from __future__ import (absolute_import, division, print_function,
+    unicode_literals)
 import deform
 
+
 class SubmitForm(deform.Form):
     def __init__(self, *args, **kwargs):
-
         if not kwargs.get('buttons'):
-            kwargs['buttons'] = ('submit', )
-
+            kwargs['buttons'] = ('submit',)
         super(SubmitForm, self).__init__(*args, **kwargs)
 
+
 class BaseForm(deform.Form):
     def __init__(self, *args, **kwargs):
         if not kwargs.get('buttons'):
-            kwargs['buttons'] = ('submit', )
-
+            kwargs['buttons'] = ('submit',)
         super(BaseForm, self).__init__(*args, **kwargs)
 
+
 class BootstrapForm(BaseForm):
-    """ This form renders out twitter bootstrap templates """
+    """This form renders out twitter bootstrap templates."""
     def __init__(self, *args, **kwargs):
         super(BootstrapForm, self).__init__(*args, **kwargs)
 
@@ -30,9 +34,9 @@ class BootstrapForm(BaseForm):
                 if not 'xlarge' in child.widget.css_class:
                     child.widget.css_class += ' xlarge'
 
+
 class HorusForm(BootstrapForm):
-    """ This is the standard form we should use through out our code, that way
-    if we decide to swap our rendering later, we only have to do it in 1 place
+    """This is the standard form we should use throughout our code, that way
+    if we decide to swap our rendering later, we only have to do it in 1 place.
     """
     pass
-
