@@ -69,7 +69,8 @@ class BaseModel(object):
                 continue
             if not key.startswith('__') and not key.startswith('_sa_'):
                 obj = getattr(self, key)
-                if isinstance(obj, datetime) or isinstance(obj, date) and convert_date:
+                if (isinstance(obj, datetime) or isinstance(obj, date)) \
+                    and convert_date:
                     obj = obj.isoformat()
                 props[key] = obj
         return props
